@@ -1,4 +1,4 @@
-#$Id: WebDAO.pm,v 1.5 2004/08/15 07:22:56 zagap Exp $
+#$Id: WebDAO.pm,v 1.8 2006/10/27 08:59:08 zag Exp $
 
 package HTML::WebDAO;
 
@@ -8,26 +8,16 @@ use HTML::WebDAO::Base;
 use HTML::WebDAO::Element;
 use HTML::WebDAO::Component;
 use HTML::WebDAO::Container;
-use HTML::WebDAO::Activator;
 use HTML::WebDAO::Engine;
 use HTML::WebDAO::Session;
 use HTML::WebDAO::Sessionco;
-use HTML::WebDAO::Sessiondb;
 use HTML::WebDAO::Sessiong;
 use HTML::WebDAO::Lib::RawHTML;
-use HTML::WebDAO::Lib::EvActivator;
-use HTML::WebDAO::Comp::VertMenu;
-use HTML::WebDAO::Comp::ListEnv;
-use HTML::WebDAO::Comp::Label;
-use HTML::WebDAO::Comp::TabMenu;
-use HTML::WebDAO::Comp::Image;
-#use HTML::WebDAO::Comp::Graph;
 our @ISA = qw();
 
-our $VERSION = '0.04';
+our $VERSION = '0.73';
 
 
-# Preloaded methods go here.
 
 1;
 __END__
@@ -54,11 +44,11 @@ http://sourceforge.net/projects/webdao
 
 =head1 AUTHOR
 
-Zahatski Aliaksandr, E<lt>zagap@users.sourceforge.netE<gt>
+Zahatski Aliaksandr, E<lt>zag@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Zahatski Aliaksandr
+Copyright 2003-2006 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
